==> lxqt-panel-2.0.1.tar.xz: lxqt-panel-2.0.1/plugin-statusnotifier/translations/statusnotifier_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Enteekateeka za kamanyisa mbeera</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Kino kye kiseera obubabaka obuvaawo bwokka kye bunaamalanga nga bulabika.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation>Ekiseera obubaka kye bulabikira:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation> dakiika</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation>Kyusa obubaka lwe bulagibwa</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation>Obubaka</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation>Lwe bulagibwa</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation>Bulijjo</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation>Kiseerabuseera</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation>Buleme okulagibwa</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.2.2.orig.tar.xz: lxqt-panel-2.2.2/plugin-statusnotifier/translations/statusnotifier_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Enteekateeka za kamanyisa mbeera</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>Vuunika ensengeka y&apos;ebiragibwa</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Kino kye kiseera obubabaka obuvaawo bwokka kye bunaamalanga nga bulabika.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Ekiseera obubaka kye bulabikira:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> dakiika</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Kyusa obubaka lwe bulagibwa</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Obubaka</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Lwe bulagibwa</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Bulijjo</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Kiseerabuseera</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Buleme okulagibwa</translation>
    </message>
</context>
</TS>
